==> haskell-fin-0.3-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fin
version:              0.3
visibility:           public
id:                   fin-0.3-2vuPZtAtb3ZLTYYKGkJELk
key:                  fin-0.3-2vuPZtAtb3ZLTYYKGkJELk
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Nat and Fin: peano naturals and finite numbers
description:
    This package provides two simple types, and some tools to work with them.
    Also on type level as @DataKinds@.

    @
    \-- Peano naturals
    data Nat = Z | S Nat

    \-- Finite naturals
    data Fin (n :: Nat) where
    \    Z :: Fin ('\''S n)
    \    S :: Fin n -> Fin ('\''Nat.S n)
    @

    [vec](https://hackage.haskell.org/package/vec) implements length-indexed
    (sized) lists using this package for indexes.

    The "Data.Fin.Enum" module let'\''s work generically with enumerations.

    See [Hasochism: the pleasure and pain of dependently typed haskell programming](https://doi.org/10.1145/2503778.2503786)
    by Sam Lindley and Conor McBride for answers to /how/ and /why/.
    Read [APLicative Programming with Naperian Functors](https://doi.org/10.1007/978-3-662-54434-1_21)
    by Jeremy Gibbons for (not so) different ones.

    === Similar packages

    * [finite-typelits](https://hackage.haskell.org/package/finite-typelits)
    . Is a great package, but uses @GHC.TypeLits@.

    * [type-natural](https://hackage.haskell.org/package/type-natural) depends
    on @singletons@ package. @fin@ will try to stay light on the dependencies,
    and support as many GHC versions as practical.

    * [peano](https://hackage.haskell.org/package/peano) is very incomplete

    * [nat](https://hackage.haskell.org/package/nat) as well.

    * [PeanoWitnesses](https://hackage.haskell.org/package/PeanoWitnesses)
    doesn'\''t use @DataKinds@.

    * [type-combinators](https://hackage.haskell.org/package/type-combinators)
    is big package too.

category:             Data, Dependent Types, Singletons, Math
abi:                  e17b6cd010c868da209b32955d1b2aba
exposed:              True
exposed-modules:
    Data.Fin Data.Nat Data.Type.Nat Data.Type.Nat.LE
    Data.Type.Nat.LE.ReflStep Data.Type.Nat.LT

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fin-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fin-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fin-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fin
hs-libraries:         HSfin-0.3-2vuPZtAtb3ZLTYYKGkJELk
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD base-4.17.2.1
    boring-0.2.2-HI9VvaC9JR142cnMpyID0P
    dec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ deepseq-1.4.8.0
    hashable-1.4.4.0-5O85VrI4oZ4EDBPYdTgwgk
    some-1.0.5-36xIADGNqiWGv9lC459cQD
    universe-base-1.1.4-FaIDPRhwcKOI8Rkm7NZcZ0

haddock-interfaces:   /usr/share/doc/haskell-fin/html/fin.haddock
haddock-html:         /usr/share/doc/haskell-fin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fin-0.3-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fin
version:              0.3
visibility:           public
id:                   fin-0.3-5XjcWzk8soz50Fh9qXFi5
key:                  fin-0.3-5XjcWzk8soz50Fh9qXFi5
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Nat and Fin: peano naturals and finite numbers
description:
    This package provides two simple types, and some tools to work with them.
    Also on type level as @DataKinds@.

    @
    \-- Peano naturals
    data Nat = Z | S Nat

    \-- Finite naturals
    data Fin (n :: Nat) where
    \    Z :: Fin ('\''S n)
    \    S :: Fin n -> Fin ('\''Nat.S n)
    @

    [vec](https://hackage.haskell.org/package/vec) implements length-indexed
    (sized) lists using this package for indexes.

    The "Data.Fin.Enum" module let'\''s work generically with enumerations.

    See [Hasochism: the pleasure and pain of dependently typed haskell programming](https://doi.org/10.1145/2503778.2503786)
    by Sam Lindley and Conor McBride for answers to /how/ and /why/.
    Read [APLicative Programming with Naperian Functors](https://doi.org/10.1007/978-3-662-54434-1_21)
    by Jeremy Gibbons for (not so) different ones.

    === Similar packages

    * [finite-typelits](https://hackage.haskell.org/package/finite-typelits)
    . Is a great package, but uses @GHC.TypeLits@.

    * [type-natural](https://hackage.haskell.org/package/type-natural) depends
    on @singletons@ package. @fin@ will try to stay light on the dependencies,
    and support as many GHC versions as practical.

    * [peano](https://hackage.haskell.org/package/peano) is very incomplete

    * [nat](https://hackage.haskell.org/package/nat) as well.

    * [PeanoWitnesses](https://hackage.haskell.org/package/PeanoWitnesses)
    doesn'\''t use @DataKinds@.

    * [type-combinators](https://hackage.haskell.org/package/type-combinators)
    is big package too.

category:             Data, Dependent Types, Singletons, Math
abi:                  db9b76236c507d3b3bbdce21e41292fc
exposed:              True
exposed-modules:
    Data.Fin Data.Nat Data.Type.Nat Data.Type.Nat.LE
    Data.Type.Nat.LE.ReflStep Data.Type.Nat.LT

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fin-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fin-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fin-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fin
hs-libraries:         HSfin-0.3-5XjcWzk8soz50Fh9qXFi5
depends:
    QuickCheck-2.14.3-3CoFGl7CagbATKlXLaYDNP base-4.17.2.1
    boring-0.2.2-HI9VvaC9JR142cnMpyID0P
    dec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ deepseq-1.4.8.0
    hashable-1.4.4.0-HA5jWeGkLE053htWZjUgjX
    some-1.0.6-ABySMdca8h36lZn3WY36IC
    universe-base-1.1.4-Fz6JWqQdVGGHWYotz47X7h

haddock-interfaces:   /usr/share/doc/haskell-fin/html/fin.haddock
haddock-html:         /usr/share/doc/haskell-fin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
